buildtest-framework
-------------------

Description
-----------
The buildtest repository is an **Automatic Test Generation Framework** for writing test cases suited to work well in a HPC environment.  This framework heavily relies that your application is built with  `EasyBuild <https://easybuild.readthedocs.io/en/latest/>`_
and your system has  `Lmod <http://lmod.readthedocs.io/en/latest/010_user.html>`_ or `Environment Modules <http://modules.sourceforge.net>`_ for managing modules

Documentation
-------------
Please see `buildtest documentation <http://buildtestdocs.readthedocs.io/en/latest/>`_  for more details.

Contact
-------
email: shahzebmsiddiqui@gmail.com
